changeset 65093:1aae62fd4a80

(custom-theme-set-variables): Sort minor modes last.
author Stefan Monnier <monnier@iro.umontreal.ca>
date Wed, 24 Aug 2005 11:49:07 +0000
parents a54c7c22bb33
children e1fcf3783add
files lisp/custom.el
diffstat 1 files changed, 7 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/custom.el	Wed Aug 24 11:36:35 2005 +0000
+++ b/lisp/custom.el	Wed Aug 24 11:49:07 2005 +0000
@@ -726,15 +726,13 @@
 			 (error "Circular custom dependency between `%s' and `%s'"
 				sym1 sym2))
 			(2-then-1 nil)
-			;; Put symbols with :require last.  The macro
-			;; define-minor-mode generates a defcustom
-			;; with a :require and a :set, where the
-			;; setter function calls the mode function.
-			;; Putting symbols with :require last ensures
-			;; that the mode function will see other
-			;; customized values rather than default
-			;; values.
-			(t (nth 3 a2)))))))
+			;; Put minor modes and symbols with :require last.
+			;; Putting minor modes last ensures that the mode
+			;; function will see other customized values rather
+			;; than default values.
+			(t (or (nth 3 a2)
+                               (eq (get sym2 'custom-set)
+                                   'custom-set-minor-mode))))))))
   (while args
     (let ((entry (car args)))
       (if (listp entry)